summaryrefslogtreecommitdiffstats
path: root/src/import/hwpf/fapi2/include
diff options
context:
space:
mode:
authorwhs <whs@us.ibm.com>2016-06-02 13:45:11 -0500
committerDaniel M. Crowell <dcrowell@us.ibm.com>2016-06-24 09:58:06 -0400
commit7e8f95823e071367bc17bb95113239324f06e5d5 (patch)
treefb3d8f7dcd3140e27c023a61da892c7e9ac02244 /src/import/hwpf/fapi2/include
parentbdf3883c19f15d8f670f74b8154d73abd6e5b58c (diff)
downloadblackbird-hostboot-7e8f95823e071367bc17bb95113239324f06e5d5.tar.gz
blackbird-hostboot-7e8f95823e071367bc17bb95113239324f06e5d5.zip
Packaging of memory vpd on Nimbus, MCA->MCS
Change from MCA to MCS target. Update decode logic. Change-Id: I071a4a1493637fdaf9119dc52874dc9984147038 Original-Change-Id: I71408c25ce33cf6e342bb704b5d173f8d98229dc RTC: 144519 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/25403 Tested-by: Jenkins Server Tested-by: PPE CI Tested-by: Hostboot CI Reviewed-by: William H. Schwartz <whs@us.ibm.com> Reviewed-by: ANDRE A. MARIN <aamarin@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/26213 Tested-by: FSP CI Jenkins
Diffstat (limited to 'src/import/hwpf/fapi2/include')
-rw-r--r--src/import/hwpf/fapi2/include/fapi2_vpd_access.H10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/import/hwpf/fapi2/include/fapi2_vpd_access.H b/src/import/hwpf/fapi2/include/fapi2_vpd_access.H
index daf8b006f..31909c566 100644
--- a/src/import/hwpf/fapi2/include/fapi2_vpd_access.H
+++ b/src/import/hwpf/fapi2/include/fapi2_vpd_access.H
@@ -37,10 +37,10 @@ namespace fapi2
constexpr uint64_t VPD_INFO_INVALID = 0xffffffffffffffff;
/// @brief Specialized class representing required VPDInfo to be used
/// in collecting VPD for the MCA target type.
/// @tparam T fapi2::TARGET_TYPE_MCA
template<>
-class VPDInfo<TARGET_TYPE_MCA>
+class VPDInfo<TARGET_TYPE_MCS>
{
public:
// @brief VPDInfo constructor
@@ -71,7 +71,7 @@ class VPDInfo<TARGET_TYPE_MCA>
/// @note passing nullptr for o_blob will return the size of the keyword
///
/// Example:
-/// fapi2::VPDInfo<fapi2::TARGET_TYPE_MCA> vpdInfo(MR_keyword);
+/// fapi2::VPDInfo<fapi2::TARGET_TYPE_MCS> vpdInfo(MR_keyword);
/// vpdInfo.iv_freq = 2667;
///
/// uint8_t * blob = NULL;
@@ -79,7 +79,7 @@ class VPDInfo<TARGET_TYPE_MCA>
/// FAPI_TRY(getVPD( mcs, vpdInfo, blob ));
/// blob = static_cast<uint8_t *>(malloc(vpdInfo.iv_size));
/// FAPI_TRY(getVPD( mcs, vpdInfo, blob ));
/// blob now contains the VPD data for the MCA.
///
template<TargetType T>
ReturnCode getVPD(const Target<T>& i_target,
@@ -37,10 +37,10 @@ namespace fapi2
constexpr uint64_t VPD_INFO_INVALID = 0xffffffffffffffff;
/// @brief Specialized class representing required VPDInfo to be used
-/// in collecting VPD for the MCA target type.
-/// @tparam T fapi2::TARGET_TYPE_MCA
+/// in collecting VPD for the MCS target type.
+/// @tparam T fapi2::TARGET_TYPE_MCS
template<>
@@ -79,7 +79,7 @@ class VPDInfo<TARGET_TYPE_MCA>
/// blob = static_cast<uint8_t *>(malloc(vpdInfo.iv_size));
/// FAPI_TRY(getVPD( mcs, vpdInfo, blob ));
-/// blob now contains the VPD data for the MCA.
+/// blob now contains the VPD data for the MCS.
///
template<TargetType T>
OpenPOWER on IntegriCloud